deepl-tr-webui v0.1.0a1

###### Quick tips

- Double click a cell or press Enter in a cell to edit.
- Press Enter or click another cell to exit the in-cell editor.
- Press the SAVEEDIT button to effect change after editing.
- To turn on debug: set LOGLEVEL=10 in Windows or export LOGLEVEL=10 in Linux and friends.

###### Project repo

https://github.com/ffreemt/deepl-tr-webui

based on pypi webui2 and some serious, messy juggling of tailwindcss, daisyui, javascript and jinja2 templates.

###### Feedback

Please join qq-group:316287378 https://jq.qq.com/?_wv=1027&k=XRCplcfg for questions and suggestions, or file an issue at the project github repo.